import copy
import json
import pathlib

from appdirs import user_config_dir

from ipc.utility.helper import list_to_set_in_dict, lower_and_strip

ROOT_DIR = pathlib.Path(__file__).parent.parent

with open(ROOT_DIR / 'validator' / 'config.json', 'r') as fp:
    CONFIG = json.load(fp)

# Repos to carry out validation for
REPOS_FOR_DATASET_LEVEL_VALIDATION = CONFIG.get('repos_for_dataset_level_validation')
REPOS_FOR_SAMPLE_LEVEL_VALIDATION = CONFIG.get('repos_for_sample_level_validation')

# DB Name
DB_NAME = CONFIG.get('job_details').get('env').get('DB_NAME')

# Declare table names
DATASET_ERRORS_TABLE = CONFIG.get('dataset_errors_table_name', 'Dataset_Errors')
SAMPLE_ERRORS_TABLE = CONFIG.get('sample_errors_table_name', 'Sample_Errors')

# Flags for which validation to run
RUN_DATASET_LEVEL_VALIDATIONS = CONFIG.get('run_dataset_level_validations', True)
RUN_SAMPLE_LEVEL_VALIDATIONS = CONFIG.get('run_sample_level_validations', True)

# Field mapping for referring to when using valid_names.json
FIELD_MAPPING = {'tissue': 'tissue',
                 'curated_tissue': 'tissue',

                 'kw_cell_type': 'cell_type',
                 'curated_cell_type': 'cell_type',

                 'kw_cell_line': 'cell_line',
                 'curated_cell_line': 'cell_line',

                 'disease': 'disease',
                 'curated_disease': 'disease',

                 'kw_drug': 'drug',
                 'curated_drug': 'drug',

                 'organism': 'organism',
                 'curated_organism': 'organism',

                 'kw_data_type': 'data_type',
                 'data_type': 'data_type',
                 }

with open(pathlib.Path(user_config_dir()) / 'polly-ipc' / 'valid_names.json', 'r') as fp:
    VALID_NAMES = json.load(fp)
VALID_NAMES_LOWERED = copy.deepcopy(VALID_NAMES)
# Creating valid name but lowered and stripped
VALID_NAMES_LOWERED = lower_and_strip(VALID_NAMES_LOWERED)

# Convert all lists to set for faster lookups
VALID_NAMES = list_to_set_in_dict(VALID_NAMES)
VALID_NAMES_LOWERED = list_to_set_in_dict(VALID_NAMES_LOWERED)
